"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.infoKeywordLength = void 0;
const filter_1 = require("../../../utils/expodash/filter");
const KEYWORD_CHARACTER_LIMIT = 100;
/**
 * Keywords are limited to 100 characters when converted to a comma separated string.
 * @see https://developer-mdn.apple.com/app-store/search/
 */
exports.infoKeywordLength = {
    id: 'apple.info.keyword.length',
    severity: 2,
    validate(config) {
        var _a;
        if (!((_a = config.apple) === null || _a === void 0 ? void 0 : _a.info) || Object.keys(config.apple.info).length === 0) {
            return null;
        }
        return Object.keys(config.apple.info)
            .map(locale => {
            var _a, _b, _c;
            const keywords = (_c = (_b = (_a = config.apple) === null || _a === void 0 ? void 0 : _a.info) === null || _b === void 0 ? void 0 : _b[locale].keywords) !== null && _c !== void 0 ? _c : [];
            const length = keywords.join(',').length;
            if (length > KEYWORD_CHARACTER_LIMIT) {
                return {
                    id: this.id,
                    severity: this.severity,
                    path: ['apple', 'info', locale, 'keywords'],
                    message: `Keywords are limited to ${KEYWORD_CHARACTER_LIMIT} characters, but found ${length}.`,
                };
            }
            return null;
        })
            .filter(filter_1.truthy);
    },
};
